Changelog
=========

0.0.5 (2011-09-06)
------------------
#. Added frame hack to resolve packages and py_modules to test, no longer needs app specific test suite.

0.0.4 (2011-09-06)
------------------
#. Refactored the app to use a callback style approach instead of monkey patching. Thanks `jezdez <https://github.com/jezdez>`_.

0.0.3 (2011-08-30)
------------------
#. More robust test settings import.

0.0.2 (2011-08-29)
------------------
#. Repeat Pep 8 errors.

0.0.1 (2011-08-29)
------------------
#. Initial release.

